summaryrefslogtreecommitdiffstats
path: root/korn/boxcontaineritem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontaineritem.h')
-rw-r--r--korn/boxcontaineritem.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korn/boxcontaineritem.h b/korn/boxcontaineritem.h
index f903feb8e..8672e4309 100644
--- a/korn/boxcontaineritem.h
+++ b/korn/boxcontaineritem.h
@@ -25,7 +25,7 @@
class KornMailSubject;
class KActionCollection;
-class KConfig;
+class TDEConfig;
class KPopupMenu;
class TDEProcess;
@@ -70,10 +70,10 @@ public:
/**
* This function reads the config. It stores the readed values in the class.
* It also sets the DCOPObject-name.
* @param config The KConfigGroup-object which contains the configuration of this box.
* @param index The index of the box used in the config-file
*/
- virtual void readConfig( KConfig* config, const int index );
+ virtual void readConfig( TDEConfig* config, const int index );
public slots:
/**
@@ -70,10 +70,10 @@ public:
* This function reads the config. It stores the readed values in the class.
* It also sets the DCOPObject-name.
- * @param config The KConfigGroup-object which contains the configuration of this box.
+ * @param config The TDEConfigGroup-object which contains the configuration of this box.
* @param index The index of the box used in the config-file
*/